# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from oci._vendor import requests  # noqa: F401
from oci._vendor import six

from oci import retry  # noqa: F401
from oci.base_client import BaseClient
from oci.config import get_config_value_or_default, validate_config
from oci.signer import Signer
from oci.util import Sentinel, get_signer_from_authentication_type, AUTHENTICATION_TYPE_FIELD_NAME
from .models import sch_type_mapping
missing = Sentinel("Missing")


class ServiceConnectorClient(object):
    """
    Use the Service Connector Hub API to transfer data between services in Oracle Cloud Infrastructure.
    For more information about Service Connector Hub, see
    [Service Connector Hub Overview](/iaas/Content/service-connector-hub/overview.htm).
    """

    def __init__(self, config, **kwargs):
        """
        Creates a new service client

        :param dict config:
            Configuration keys and values as per `SDK and Tool Configuration <https://docs.cloud.oracle.com/Content/API/Concepts/sdkconfig.htm>`__.
            The :py:meth:`~oci.config.from_file` method can be used to load configuration from a file. Alternatively, a ``dict`` can be passed. You can validate_config
            the dict using :py:meth:`~oci.config.validate_config`

        :param str service_endpoint: (optional)
            The endpoint of the service to call using this client. For example ``https://iaas.us-ashburn-1.oraclecloud.com``. If this keyword argument is
            not provided then it will be derived using the region in the config parameter. You should only provide this keyword argument if you have an explicit
            need to specify a service endpoint.

        :param timeout: (optional)
            The connection and read timeouts for the client. The default values are connection timeout 10 seconds and read timeout 60 seconds. This keyword argument can be provided
            as a single float, in which case the value provided is used for both the read and connection timeouts, or as a tuple of two floats. If
            a tuple is provided then the first value is used as the connection timeout and the second value as the read timeout.
        :type timeout: float or tuple(float, float)

        :param signer: (optional)
            The signer to use when signing requests made by the service client. The default is to use a :py:class:`~oci.signer.Signer` based on the values
            provided in the config parameter.

            One use case for this parameter is for `Instance Principals authentication <https://docs.cloud.oracle.com/Content/Identity/Tasks/callingservicesfrominstances.htm>`__
            by passing an instance of :py:class:`~oci.auth.signers.InstancePrincipalsSecurityTokenSigner` as the value for this keyword argument
        :type signer: :py:class:`~oci.signer.AbstractBaseSigner`

        :param obj retry_strategy: (optional)
            A retry strategy to apply to all calls made by this service client (i.e. at the client level). There is no retry strategy applied by default.
            Retry strategies can also be applied at the operation level by passing a ``retry_strategy`` keyword argument as part of calling the operation.
            Any value provided at the operation level will override whatever is specified at the client level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.
        """
        validate_config(config, signer=kwargs.get('signer'))
        if 'signer' in kwargs:
            signer = kwargs['signer']

        elif AUTHENTICATION_TYPE_FIELD_NAME in config:
            signer = get_signer_from_authentication_type(config)

        else:
            signer = Signer(
                tenancy=config["tenancy"],
                user=config["user"],
                fingerprint=config["fingerprint"],
                private_key_file_location=config.get("key_file"),
                pass_phrase=get_config_value_or_default(config, "pass_phrase"),
                private_key_content=config.get("key_content")
            )

        base_client_init_kwargs = {
            'regional_client': True,
            'service_endpoint': kwargs.get('service_endpoint'),
            'base_path': '/20200909',
            'service_endpoint_template': 'https://service-connector-hub.{region}.oci.{secondLevelDomain}',
            'skip_deserialization': kwargs.get('skip_deserialization', False)
        }
        if 'timeout' in kwargs:
            base_client_init_kwargs['timeout'] = kwargs.get('timeout')
        self.base_client = BaseClient("service_connector", config, signer, sch_type_mapping, **base_client_init_kwargs)
        self.retry_strategy = kwargs.get('retry_strategy')

    def activate_service_connector(self, service_connector_id, **kwargs):
        """
        Activates the specified service connector.

        After you send your request, the service connector's state is temporarily
        UPDATING. When the state changes to ACTIVE, data begins transferring from the
        source service to the target service. For instructions on activating service
        connectors, see
        `To activate a service connector`__.

        __ https://docs.cloud.oracle.com/iaas/Content/service-connector-hub/managingconnectors.htm#activate


        :param str service_connector_id: (required)
            The `OCID`__ of the service connector.

            __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm

        :param str opc_retry_token: (optional)
            A token that uniquely identifies a request so it can be retried in case of a timeout or
            server error without risk of executing that same action again. Retry tokens expire after 24
            hours, but can be invalidated before then due to conflicting operations. For example, if a resource
            has been deleted and purged from the system, then a retry of the original creation request
            might be rejected.

        :param str if_match: (optional)
            For optimistic concurrency control. In the PUT or DELETE call
            for a resource, set the `if-match` parameter to the value of the
            etag from a previous GET or POST response for that resource.
            The resource will be updated or deleted only if the etag you
            provide matches the resource's current etag value.

        :param str opc_request_id: (optional)
            The unique Oracle-assigned identifier for the request.
            If you need to contact Oracle about a particular request, please provide the request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type None
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/sch/activate_service_connector.py.html>`__ to see an example of how to use activate_service_connector API.
        """
        resource_path = "/serviceConnectors/{serviceConnectorId}/actions/activate"
        method = "POST"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "opc_retry_token",
            "if_match",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "activate_service_connector got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "serviceConnectorId": service_connector_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-retry-token": kwargs.get("opc_retry_token", missing),
            "if-match": kwargs.get("if_match", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_retry_token_if_needed(header_params)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params)

    def change_service_connector_compartment(self, service_connector_id, change_service_connector_compartment_details, **kwargs):
        """
        Moves a service connector into a different compartment within the same tenancy.
        For information about moving resources between compartments, see
        `Moving Resources to a Different Compartment`__.

        When provided, If-Match is checked against ETag values of the resource.

        __ https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes


        :param str service_connector_id: (required)
            The `OCID`__ of the service connector.

            __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm

        :param oci.sch.models.ChangeServiceConnectorCompartmentDetails change_service_connector_compartment_details: (required)
            The configuration details for moving a service connector to a different compartment.

        :param str if_match: (optional)
            For optimistic concurrency control. In the PUT or DELETE call
            for a resource, set the `if-match` parameter to the value of the
            etag from a previous GET or POST response for that resource.
            The resource will be updated or deleted only if the etag you
            provide matches the resource's current etag value.

        :param str opc_request_id: (optional)
            The unique Oracle-assigned identifier for the request.
            If you need to contact Oracle about a particular request, please provide the request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type None
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/sch/change_service_connector_compartment.py.html>`__ to see an example of how to use change_service_connector_compartment API.
        """
        resource_path = "/serviceConnectors/{serviceConnectorId}/actions/changeCompartment"
        method = "POST"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "if_match",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "change_service_connector_compartment got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "serviceConnectorId": service_connector_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "if-match": kwargs.get("if_match", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=change_service_connector_compartment_details)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=change_service_connector_compartment_details)

    def create_service_connector(self, create_service_connector_details, **kwargs):
        """
        Creates a new service connector in the specified compartment.
        A service connector is a logically defined flow for moving data from
        a source service to a destination service in Oracle Cloud Infrastructure.
        For general information about service connectors, see
        `Service Connector Hub Overview`__.

        For purposes of access control, you must provide the
        `OCID`__ of the compartment where
        you want the service connector to reside. Notice that the service connector
        doesn't have to be in the same compartment as the source or target services.
        For information about access control and compartments, see
        `Overview of the IAM Service`__.

        After you send your request, the new service connector's state is temporarily
        CREATING. When the state changes to ACTIVE, data begins transferring from the
        source service to the target service. For instructions on deactivating and
        activating service connectors, see
        `To activate or deactivate a service connector`__.

        __ https://docs.cloud.oracle.com/iaas/Content/service-connector-hub/overview.htm
        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/iaas/Content/Identity/Concepts/overview.htm
        __ https://docs.cloud.oracle.com/iaas/Content/service-connector-hub/overview.htm


        :param oci.sch.models.CreateServiceConnectorDetails create_service_connector_details: (required)
            Configuration details for the new service connector.

        :param str opc_retry_token: (optional)
            A token that uniquely identifies a request so it can be retried in case of a timeout or
            server error without risk of executing that same action again. Retry tokens expire after 24
            hours, but can be invalidated before then due to conflicting operations. For example, if a resource
            has been deleted and purged from the system, then a retry of the original creation request
            might be rejected.

        :param str opc_request_id: (optional)
            The unique Oracle-assigned identifier for the request.
            If you need to contact Oracle about a particular request, please provide the request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type None
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/sch/create_service_connector.py.html>`__ to see an example of how to use create_service_connector API.
        """
        resource_path = "/serviceConnectors"
        method = "POST"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "opc_retry_token",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "create_service_connector got unknown kwargs: {!r}".format(extra_kwargs))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-retry-token": kwargs.get("opc_retry_token", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_retry_token_if_needed(header_params)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                header_params=header_params,
                body=create_service_connector_details)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                header_params=header_params,
                body=create_service_connector_details)

    def deactivate_service_connector(self, service_connector_id, **kwargs):
        """
        Deactivates the specified service connector.

        After you send your request, the service connector's state is temporarily
        UPDATING and any data transfer stops. The state then changes to INACTIVE.
        For instructions on deactivating service connectors, see
        `To deactivate a service connector`__.

        __ https://docs.cloud.oracle.com/iaas/Content/service-connector-hub/managingconnectors.htm#deactivate


        :param str service_connector_id: (required)
            The `OCID`__ of the service connector.

            __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm

        :param str opc_retry_token: (optional)
            A token that uniquely identifies a request so it can be retried in case of a timeout or
            server error without risk of executing that same action again. Retry tokens expire after 24
            hours, but can be invalidated before then due to conflicting operations. For example, if a resource
            has been deleted and purged from the system, then a retry of the original creation request
            might be rejected.

        :param str if_match: (optional)
            For optimistic concurrency control. In the PUT or DELETE call
            for a resource, set the `if-match` parameter to the value of the
            etag from a previous GET or POST response for that resource.
            The resource will be updated or deleted only if the etag you
            provide matches the resource's current etag value.

        :param str opc_request_id: (optional)
            The unique Oracle-assigned identifier for the request.
            If you need to contact Oracle about a particular request, please provide the request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type None
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/sch/deactivate_service_connector.py.html>`__ to see an example of how to use deactivate_service_connector API.
        """
        resource_path = "/serviceConnectors/{serviceConnectorId}/actions/deactivate"
        method = "POST"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "opc_retry_token",
            "if_match",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "deactivate_service_connector got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "serviceConnectorId": service_connector_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-retry-token": kwargs.get("opc_retry_token", missing),
            "if-match": kwargs.get("if_match", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_retry_token_if_needed(header_params)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params)

    def delete_service_connector(self, service_connector_id, **kwargs):
        """
        Deletes the specified service connector.

        After you send your request, the service connector's state is temporarily
        DELETING and any data transfer stops. The state then changes to DELETED.


        :param str service_connector_id: (required)
            The `OCID`__ of the service connector.

            __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm

        :param str if_match: (optional)
            For optimistic concurrency control. In the PUT or DELETE call
            for a resource, set the `if-match` parameter to the value of the
            etag from a previous GET or POST response for that resource.
            The resource will be updated or deleted only if the etag you
            provide matches the resource's current etag value.

        :param str opc_request_id: (optional)
            The unique Oracle-assigned identifier for the request.
            If you need to contact Oracle about a particular request, please provide the request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type None
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/sch/delete_service_connector.py.html>`__ to see an example of how to use delete_service_connector API.
        """
        resource_path = "/serviceConnectors/{serviceConnectorId}"
        method = "DELETE"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "if_match",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "delete_service_connector got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "serviceConnectorId": service_connector_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "if-match": kwargs.get("if_match", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params)

    def get_service_connector(self, service_connector_id, **kwargs):
        """
        Gets the specified service connector's configuration information.


        :param str service_connector_id: (required)
            The `OCID`__ of the service connector.

            __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm

        :param str opc_request_id: (optional)
            The unique Oracle-assigned identifier for the request.
            If you need to contact Oracle about a particular request, please provide the request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.sch.models.ServiceConnector`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/sch/get_service_connector.py.html>`__ to see an example of how to use get_service_connector API.
        """
        resource_path = "/serviceConnectors/{serviceConnectorId}"
        method = "GET"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "get_service_connector got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "serviceConnectorId": service_connector_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                response_type="ServiceConnector")
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                response_type="ServiceConnector")

    def get_work_request(self, work_request_id, **kwargs):
        """
        Gets the details of the specified work request.


        :param str work_request_id: (required)
            The `OCID`__ of the work request.

            __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm

        :param str opc_request_id: (optional)
            The unique Oracle-assigned identifier for the request.
            If you need to contact Oracle about a particular request, please provide the request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.sch.models.WorkRequest`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/sch/get_work_request.py.html>`__ to see an example of how to use get_work_request API.
        """
        resource_path = "/workRequests/{workRequestId}"
        method = "GET"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "get_work_request got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "workRequestId": work_request_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                response_type="WorkRequest")
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                response_type="WorkRequest")

    def list_service_connectors(self, compartment_id, **kwargs):
        """
        Lists service connectors in the specified compartment.


        :param str compartment_id: (required)
            The `OCID`__ of the compartment for this request.

            __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm

        :param str lifecycle_state: (optional)
            A filter to return only resources that match the given lifecycle state.

            Example: `ACTIVE`

            Allowed values are: "CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED"

        :param str display_name: (optional)
            A filter to return only resources that match the given display name exactly.

            Example: `example_service_connector`

        :param int limit: (optional)
            For list pagination. The maximum number of results per page, or items to return
            in a paginated \"List\" call. For important details about how pagination works, see
            `List Pagination`__.

            __ https://docs.cloud.oracle.com/iaas/Content/API/Concepts/usingapi.htm#nine

        :param str page: (optional)
            For list pagination. The value of the opc-next-page response header from the previous
            \"List\" call. For important details about how pagination works, see
            `List Pagination`__.

            __ https://docs.cloud.oracle.com/iaas/Content/API/Concepts/usingapi.htm#nine

        :param str sort_order: (optional)
            The sort order to use, either 'asc' or 'desc'.

            Allowed values are: "ASC", "DESC"

        :param str sort_by: (optional)
            The field to sort by. Only one sort order may be provided. Default order for `timeCreated` is descending.
            Default order for `displayName` is ascending. If no value is specified `timeCreated` is default.

            Allowed values are: "timeCreated", "displayName"

        :param str opc_request_id: (optional)
            The unique Oracle-assigned identifier for the request.
            If you need to contact Oracle about a particular request, please provide the request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.sch.models.ServiceConnectorCollection`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/sch/list_service_connectors.py.html>`__ to see an example of how to use list_service_connectors API.
        """
        resource_path = "/serviceConnectors"
        method = "GET"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "lifecycle_state",
            "display_name",
            "limit",
            "page",
            "sort_order",
            "sort_by",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "list_service_connectors got unknown kwargs: {!r}".format(extra_kwargs))

        if 'lifecycle_state' in kwargs:
            lifecycle_state_allowed_values = ["CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED"]
            if kwargs['lifecycle_state'] not in lifecycle_state_allowed_values:
                raise ValueError(
                    "Invalid value for `lifecycle_state`, must be one of {0}".format(lifecycle_state_allowed_values)
                )

        if 'sort_order' in kwargs:
            sort_order_allowed_values = ["ASC", "DESC"]
            if kwargs['sort_order'] not in sort_order_allowed_values:
                raise ValueError(
                    "Invalid value for `sort_order`, must be one of {0}".format(sort_order_allowed_values)
                )

        if 'sort_by' in kwargs:
            sort_by_allowed_values = ["timeCreated", "displayName"]
            if kwargs['sort_by'] not in sort_by_allowed_values:
                raise ValueError(
                    "Invalid value for `sort_by`, must be one of {0}".format(sort_by_allowed_values)
                )

        query_params = {
            "compartmentId": compartment_id,
            "lifecycleState": kwargs.get("lifecycle_state", missing),
            "displayName": kwargs.get("display_name", missing),
            "limit": kwargs.get("limit", missing),
            "page": kwargs.get("page", missing),
            "sortOrder": kwargs.get("sort_order", missing),
            "sortBy": kwargs.get("sort_by", missing)
        }
        query_params = {k: v for (k, v) in six.iteritems(query_params) if v is not missing and v is not None}

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                query_params=query_params,
                header_params=header_params,
                response_type="ServiceConnectorCollection")
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                query_params=query_params,
                header_params=header_params,
                response_type="ServiceConnectorCollection")

    def list_work_request_errors(self, work_request_id, **kwargs):
        """
        Lists work request errors for the specified work request. Results are paginated.


        :param str work_request_id: (required)
            The `OCID`__ of the work request.

            __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm

        :param str opc_request_id: (optional)
            The unique Oracle-assigned identifier for the request.
            If you need to contact Oracle about a particular request, please provide the request ID.

        :param str page: (optional)
            For list pagination. The value of the opc-next-page response header from the previous
            \"List\" call. For important details about how pagination works, see
            `List Pagination`__.

            __ https://docs.cloud.oracle.com/iaas/Content/API/Concepts/usingapi.htm#nine

        :param int limit: (optional)
            For list pagination. The maximum number of results per page, or items to return
            in a paginated \"List\" call. For important details about how pagination works, see
            `List Pagination`__.

            __ https://docs.cloud.oracle.com/iaas/Content/API/Concepts/usingapi.htm#nine

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.sch.models.WorkRequestErrorCollection`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/sch/list_work_request_errors.py.html>`__ to see an example of how to use list_work_request_errors API.
        """
        resource_path = "/workRequests/{workRequestId}/errors"
        method = "GET"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "opc_request_id",
            "page",
            "limit"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "list_work_request_errors got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "workRequestId": work_request_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        query_params = {
            "page": kwargs.get("page", missing),
            "limit": kwargs.get("limit", missing)
        }
        query_params = {k: v for (k, v) in six.iteritems(query_params) if v is not missing and v is not None}

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                query_params=query_params,
                header_params=header_params,
                response_type="WorkRequestErrorCollection")
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                query_params=query_params,
                header_params=header_params,
                response_type="WorkRequestErrorCollection")

    def list_work_request_logs(self, work_request_id, **kwargs):
        """
        Lists logs for the specified work request. Results are paginated.


        :param str work_request_id: (required)
            The `OCID`__ of the work request.

            __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm

        :param str opc_request_id: (optional)
            The unique Oracle-assigned identifier for the request.
            If you need to contact Oracle about a particular request, please provide the request ID.

        :param str page: (optional)
            For list pagination. The value of the opc-next-page response header from the previous
            \"List\" call. For important details about how pagination works, see
            `List Pagination`__.

            __ https://docs.cloud.oracle.com/iaas/Content/API/Concepts/usingapi.htm#nine

        :param int limit: (optional)
            For list pagination. The maximum number of results per page, or items to return
            in a paginated \"List\" call. For important details about how pagination works, see
            `List Pagination`__.

            __ https://docs.cloud.oracle.com/iaas/Content/API/Concepts/usingapi.htm#nine

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.sch.models.WorkRequestLogEntryCollection`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/sch/list_work_request_logs.py.html>`__ to see an example of how to use list_work_request_logs API.
        """
        resource_path = "/workRequests/{workRequestId}/logs"
        method = "GET"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "opc_request_id",
            "page",
            "limit"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "list_work_request_logs got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "workRequestId": work_request_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        query_params = {
            "page": kwargs.get("page", missing),
            "limit": kwargs.get("limit", missing)
        }
        query_params = {k: v for (k, v) in six.iteritems(query_params) if v is not missing and v is not None}

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                query_params=query_params,
                header_params=header_params,
                response_type="WorkRequestLogEntryCollection")
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                query_params=query_params,
                header_params=header_params,
                response_type="WorkRequestLogEntryCollection")

    def list_work_requests(self, compartment_id, **kwargs):
        """
        Lists the work requests in the specified compartment.


        :param str compartment_id: (required)
            The `OCID`__ of the compartment for this request.

            __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm

        :param str opc_request_id: (optional)
            The unique Oracle-assigned identifier for the request.
            If you need to contact Oracle about a particular request, please provide the request ID.

        :param str page: (optional)
            For list pagination. The value of the opc-next-page response header from the previous
            \"List\" call. For important details about how pagination works, see
            `List Pagination`__.

            __ https://docs.cloud.oracle.com/iaas/Content/API/Concepts/usingapi.htm#nine

        :param int limit: (optional)
            For list pagination. The maximum number of results per page, or items to return
            in a paginated \"List\" call. For important details about how pagination works, see
            `List Pagination`__.

            __ https://docs.cloud.oracle.com/iaas/Content/API/Concepts/usingapi.htm#nine

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.sch.models.WorkRequestCollection`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/sch/list_work_requests.py.html>`__ to see an example of how to use list_work_requests API.
        """
        resource_path = "/workRequests"
        method = "GET"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "opc_request_id",
            "page",
            "limit"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "list_work_requests got unknown kwargs: {!r}".format(extra_kwargs))

        query_params = {
            "compartmentId": compartment_id,
            "page": kwargs.get("page", missing),
            "limit": kwargs.get("limit", missing)
        }
        query_params = {k: v for (k, v) in six.iteritems(query_params) if v is not missing and v is not None}

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                query_params=query_params,
                header_params=header_params,
                response_type="WorkRequestCollection")
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                query_params=query_params,
                header_params=header_params,
                response_type="WorkRequestCollection")

    def update_service_connector(self, service_connector_id, update_service_connector_details, **kwargs):
        """
        Updates the configuration information for the specified service connector.

        After you send your request, the service connector's state is temporarily
        UPDATING and any data transfer pauses. The state then changes back to its
        original value: if ACTIVE, then data transfer resumes.


        :param str service_connector_id: (required)
            The `OCID`__ of the service connector.

            __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm

        :param oci.sch.models.UpdateServiceConnectorDetails update_service_connector_details: (required)
            The information to be updated.

        :param str if_match: (optional)
            For optimistic concurrency control. In the PUT or DELETE call
            for a resource, set the `if-match` parameter to the value of the
            etag from a previous GET or POST response for that resource.
            The resource will be updated or deleted only if the etag you
            provide matches the resource's current etag value.

        :param str opc_request_id: (optional)
            The unique Oracle-assigned identifier for the request.
            If you need to contact Oracle about a particular request, please provide the request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type None
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/sch/update_service_connector.py.html>`__ to see an example of how to use update_service_connector API.
        """
        resource_path = "/serviceConnectors/{serviceConnectorId}"
        method = "PUT"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "if_match",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "update_service_connector got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "serviceConnectorId": service_connector_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "if-match": kwargs.get("if_match", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=update_service_connector_details)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=update_service_connector_details)



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SuppressionSummary(object):
    """
    The full information representing a suppression.
    """

    #: A constant which can be used with the reason property of a SuppressionSummary.
    #: This constant has a value of "UNKNOWN"
    REASON_UNKNOWN = "UNKNOWN"

    #: A constant which can be used with the reason property of a SuppressionSummary.
    #: This constant has a value of "HARDBOUNCE"
    REASON_HARDBOUNCE = "HARDBOUNCE"

    #: A constant which can be used with the reason property of a SuppressionSummary.
    #: This constant has a value of "COMPLAINT"
    REASON_COMPLAINT = "COMPLAINT"

    #: A constant which can be used with the reason property of a SuppressionSummary.
    #: This constant has a value of "MANUAL"
    REASON_MANUAL = "MANUAL"

    #: A constant which can be used with the reason property of a SuppressionSummary.
    #: This constant has a value of "SOFTBOUNCE"
    REASON_SOFTBOUNCE = "SOFTBOUNCE"

    #: A constant which can be used with the reason property of a SuppressionSummary.
    #: This constant has a value of "UNSUBSCRIBE"
    REASON_UNSUBSCRIBE = "UNSUBSCRIBE"

    def __init__(self, **kwargs):
        """
        Initializes a new SuppressionSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this SuppressionSummary.
        :type compartment_id: str

        :param email_address:
            The value to assign to the email_address property of this SuppressionSummary.
        :type email_address: str

        :param id:
            The value to assign to the id property of this SuppressionSummary.
        :type id: str

        :param reason:
            The value to assign to the reason property of this SuppressionSummary.
            Allowed values for this property are: "UNKNOWN", "HARDBOUNCE", "COMPLAINT", "MANUAL", "SOFTBOUNCE", "UNSUBSCRIBE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type reason: str

        :param time_created:
            The value to assign to the time_created property of this SuppressionSummary.
        :type time_created: datetime

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'email_address': 'str',
            'id': 'str',
            'reason': 'str',
            'time_created': 'datetime'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'email_address': 'emailAddress',
            'id': 'id',
            'reason': 'reason',
            'time_created': 'timeCreated'
        }

        self._compartment_id = None
        self._email_address = None
        self._id = None
        self._reason = None
        self._time_created = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this SuppressionSummary.
        The OCID for the compartment.


        :return: The compartment_id of this SuppressionSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this SuppressionSummary.
        The OCID for the compartment.


        :param compartment_id: The compartment_id of this SuppressionSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def email_address(self):
        """
        **[Required]** Gets the email_address of this SuppressionSummary.
        The email address of the suppression.


        :return: The email_address of this SuppressionSummary.
        :rtype: str
        """
        return self._email_address

    @email_address.setter
    def email_address(self, email_address):
        """
        Sets the email_address of this SuppressionSummary.
        The email address of the suppression.


        :param email_address: The email_address of this SuppressionSummary.
        :type: str
        """
        self._email_address = email_address

    @property
    def id(self):
        """
        **[Required]** Gets the id of this SuppressionSummary.
        The unique OCID of the suppression.


        :return: The id of this SuppressionSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this SuppressionSummary.
        The unique OCID of the suppression.


        :param id: The id of this SuppressionSummary.
        :type: str
        """
        self._id = id

    @property
    def reason(self):
        """
        Gets the reason of this SuppressionSummary.
        The reason that the email address was suppressed.

        Allowed values for this property are: "UNKNOWN", "HARDBOUNCE", "COMPLAINT", "MANUAL", "SOFTBOUNCE", "UNSUBSCRIBE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The reason of this SuppressionSummary.
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """
        Sets the reason of this SuppressionSummary.
        The reason that the email address was suppressed.


        :param reason: The reason of this SuppressionSummary.
        :type: str
        """
        allowed_values = ["UNKNOWN", "HARDBOUNCE", "COMPLAINT", "MANUAL", "SOFTBOUNCE", "UNSUBSCRIBE"]
        if not value_allowed_none_or_none_sentinel(reason, allowed_values):
            reason = 'UNKNOWN_ENUM_VALUE'
        self._reason = reason

    @property
    def time_created(self):
        """
        Gets the time_created of this SuppressionSummary.
        The date and time a recipient's email address was added to the
        suppression list, in \"YYYY-MM-ddThh:mmZ\" format with a Z offset, as
        defined by RFC 3339.


        :return: The time_created of this SuppressionSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this SuppressionSummary.
        The date and time a recipient's email address was added to the
        suppression list, in \"YYYY-MM-ddThh:mmZ\" format with a Z offset, as
        defined by RFC 3339.


        :param time_created: The time_created of this SuppressionSummary.
        :type: datetime
        """
        self._time_created = time_created

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class WorkflowMonitor(object):
    """
    The workflow monitor for this work request.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new WorkflowMonitor object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param workflow_name:
            The value to assign to the workflow_name property of this WorkflowMonitor.
        :type workflow_name: str

        :param resource_name:
            The value to assign to the resource_name property of this WorkflowMonitor.
        :type resource_name: str

        :param workflow_steps:
            The value to assign to the workflow_steps property of this WorkflowMonitor.
        :type workflow_steps: list[oci.oce.models.WorkflowStep]

        """
        self.swagger_types = {
            'workflow_name': 'str',
            'resource_name': 'str',
            'workflow_steps': 'list[WorkflowStep]'
        }

        self.attribute_map = {
            'workflow_name': 'workflowName',
            'resource_name': 'resourceName',
            'workflow_steps': 'workflowSteps'
        }

        self._workflow_name = None
        self._resource_name = None
        self._workflow_steps = None

    @property
    def workflow_name(self):
        """
        Gets the workflow_name of this WorkflowMonitor.
        workflow name for this work request


        :return: The workflow_name of this WorkflowMonitor.
        :rtype: str
        """
        return self._workflow_name

    @workflow_name.setter
    def workflow_name(self, workflow_name):
        """
        Sets the workflow_name of this WorkflowMonitor.
        workflow name for this work request


        :param workflow_name: The workflow_name of this WorkflowMonitor.
        :type: str
        """
        self._workflow_name = workflow_name

    @property
    def resource_name(self):
        """
        Gets the resource_name of this WorkflowMonitor.
        resource name for this work request


        :return: The resource_name of this WorkflowMonitor.
        :rtype: str
        """
        return self._resource_name

    @resource_name.setter
    def resource_name(self, resource_name):
        """
        Sets the resource_name of this WorkflowMonitor.
        resource name for this work request


        :param resource_name: The resource_name of this WorkflowMonitor.
        :type: str
        """
        self._resource_name = resource_name

    @property
    def workflow_steps(self):
        """
        Gets the workflow_steps of this WorkflowMonitor.
        Workflow step of workflow monitor.


        :return: The workflow_steps of this WorkflowMonitor.
        :rtype: list[oci.oce.models.WorkflowStep]
        """
        return self._workflow_steps

    @workflow_steps.setter
    def workflow_steps(self, workflow_steps):
        """
        Sets the workflow_steps of this WorkflowMonitor.
        Workflow step of workflow monitor.


        :param workflow_steps: The workflow_steps of this WorkflowMonitor.
        :type: list[oci.oce.models.WorkflowStep]
        """
        self._workflow_steps = workflow_steps

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class KeyShape(object):
    """
    The cryptographic properties of a key.
    """

    #: A constant which can be used with the algorithm property of a KeyShape.
    #: This constant has a value of "AES"
    ALGORITHM_AES = "AES"

    #: A constant which can be used with the algorithm property of a KeyShape.
    #: This constant has a value of "RSA"
    ALGORITHM_RSA = "RSA"

    #: A constant which can be used with the algorithm property of a KeyShape.
    #: This constant has a value of "ECDSA"
    ALGORITHM_ECDSA = "ECDSA"

    #: A constant which can be used with the curve_id property of a KeyShape.
    #: This constant has a value of "NIST_P256"
    CURVE_ID_NIST_P256 = "NIST_P256"

    #: A constant which can be used with the curve_id property of a KeyShape.
    #: This constant has a value of "NIST_P384"
    CURVE_ID_NIST_P384 = "NIST_P384"

    #: A constant which can be used with the curve_id property of a KeyShape.
    #: This constant has a value of "NIST_P521"
    CURVE_ID_NIST_P521 = "NIST_P521"

    def __init__(self, **kwargs):
        """
        Initializes a new KeyShape object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param algorithm:
            The value to assign to the algorithm property of this KeyShape.
            Allowed values for this property are: "AES", "RSA", "ECDSA", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type algorithm: str

        :param length:
            The value to assign to the length property of this KeyShape.
        :type length: int

        :param curve_id:
            The value to assign to the curve_id property of this KeyShape.
            Allowed values for this property are: "NIST_P256", "NIST_P384", "NIST_P521", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type curve_id: str

        """
        self.swagger_types = {
            'algorithm': 'str',
            'length': 'int',
            'curve_id': 'str'
        }

        self.attribute_map = {
            'algorithm': 'algorithm',
            'length': 'length',
            'curve_id': 'curveId'
        }

        self._algorithm = None
        self._length = None
        self._curve_id = None

    @property
    def algorithm(self):
        """
        **[Required]** Gets the algorithm of this KeyShape.
        The algorithm used by a key's key versions to encrypt or decrypt.

        Allowed values for this property are: "AES", "RSA", "ECDSA", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The algorithm of this KeyShape.
        :rtype: str
        """
        return self._algorithm

    @algorithm.setter
    def algorithm(self, algorithm):
        """
        Sets the algorithm of this KeyShape.
        The algorithm used by a key's key versions to encrypt or decrypt.


        :param algorithm: The algorithm of this KeyShape.
        :type: str
        """
        allowed_values = ["AES", "RSA", "ECDSA"]
        if not value_allowed_none_or_none_sentinel(algorithm, allowed_values):
            algorithm = 'UNKNOWN_ENUM_VALUE'
        self._algorithm = algorithm

    @property
    def length(self):
        """
        **[Required]** Gets the length of this KeyShape.
        The length of the key in bytes, expressed as an integer. Supported values include the following:
          - AES: 16, 24, or 32
          - RSA: 256, 384, or 512
          - ECDSA: 32, 48, or 66


        :return: The length of this KeyShape.
        :rtype: int
        """
        return self._length

    @length.setter
    def length(self, length):
        """
        Sets the length of this KeyShape.
        The length of the key in bytes, expressed as an integer. Supported values include the following:
          - AES: 16, 24, or 32
          - RSA: 256, 384, or 512
          - ECDSA: 32, 48, or 66


        :param length: The length of this KeyShape.
        :type: int
        """
        self._length = length

    @property
    def curve_id(self):
        """
        Gets the curve_id of this KeyShape.
        Supported curve IDs for ECDSA keys.

        Allowed values for this property are: "NIST_P256", "NIST_P384", "NIST_P521", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The curve_id of this KeyShape.
        :rtype: str
        """
        return self._curve_id

    @curve_id.setter
    def curve_id(self, curve_id):
        """
        Sets the curve_id of this KeyShape.
        Supported curve IDs for ECDSA keys.


        :param curve_id: The curve_id of this KeyShape.
        :type: str
        """
        allowed_values = ["NIST_P256", "NIST_P384", "NIST_P521"]
        if not value_allowed_none_or_none_sentinel(curve_id, allowed_values):
            curve_id = 'UNKNOWN_ENUM_VALUE'
        self._curve_id = curve_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class References(object):
    """
    References to the sections of STIG, CIS, and/or GDPR relevant to the current finding.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new References object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param stig:
            The value to assign to the stig property of this References.
        :type stig: str

        :param cis:
            The value to assign to the cis property of this References.
        :type cis: str

        :param gdpr:
            The value to assign to the gdpr property of this References.
        :type gdpr: str

        """
        self.swagger_types = {
            'stig': 'str',
            'cis': 'str',
            'gdpr': 'str'
        }

        self.attribute_map = {
            'stig': 'stig',
            'cis': 'cis',
            'gdpr': 'gdpr'
        }

        self._stig = None
        self._cis = None
        self._gdpr = None

    @property
    def stig(self):
        """
        Gets the stig of this References.
        Relevant section from STIG.


        :return: The stig of this References.
        :rtype: str
        """
        return self._stig

    @stig.setter
    def stig(self, stig):
        """
        Sets the stig of this References.
        Relevant section from STIG.


        :param stig: The stig of this References.
        :type: str
        """
        self._stig = stig

    @property
    def cis(self):
        """
        Gets the cis of this References.
        Relevant section from CIS.


        :return: The cis of this References.
        :rtype: str
        """
        return self._cis

    @cis.setter
    def cis(self, cis):
        """
        Sets the cis of this References.
        Relevant section from CIS.


        :param cis: The cis of this References.
        :type: str
        """
        self._cis = cis

    @property
    def gdpr(self):
        """
        Gets the gdpr of this References.
        Relevant section from GDPR.


        :return: The gdpr of this References.
        :rtype: str
        """
        return self._gdpr

    @gdpr.setter
    def gdpr(self, gdpr):
        """
        Sets the gdpr of this References.
        Relevant section from GDPR.


        :param gdpr: The gdpr of this References.
        :type: str
        """
        self._gdpr = gdpr

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ServiceCatalogSummary(object):
    """
    The model for a summary of an Oracle Cloud Infrastructure service catalog.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ServiceCatalogSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this ServiceCatalogSummary.
        :type id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this ServiceCatalogSummary.
        :type lifecycle_state: str

        :param compartment_id:
            The value to assign to the compartment_id property of this ServiceCatalogSummary.
        :type compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this ServiceCatalogSummary.
        :type display_name: str

        :param time_created:
            The value to assign to the time_created property of this ServiceCatalogSummary.
        :type time_created: datetime

        """
        self.swagger_types = {
            'id': 'str',
            'lifecycle_state': 'str',
            'compartment_id': 'str',
            'display_name': 'str',
            'time_created': 'datetime'
        }

        self.attribute_map = {
            'id': 'id',
            'lifecycle_state': 'lifecycleState',
            'compartment_id': 'compartmentId',
            'display_name': 'displayName',
            'time_created': 'timeCreated'
        }

        self._id = None
        self._lifecycle_state = None
        self._compartment_id = None
        self._display_name = None
        self._time_created = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this ServiceCatalogSummary.
        The unique identifier for the Service catalog.


        :return: The id of this ServiceCatalogSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ServiceCatalogSummary.
        The unique identifier for the Service catalog.


        :param id: The id of this ServiceCatalogSummary.
        :type: str
        """
        self._id = id

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this ServiceCatalogSummary.
        The lifecycle state of the service catalog.


        :return: The lifecycle_state of this ServiceCatalogSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this ServiceCatalogSummary.
        The lifecycle state of the service catalog.


        :param lifecycle_state: The lifecycle_state of this ServiceCatalogSummary.
        :type: str
        """
        self._lifecycle_state = lifecycle_state

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this ServiceCatalogSummary.
        The Compartment id where the service catalog exists.


        :return: The compartment_id of this ServiceCatalogSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this ServiceCatalogSummary.
        The Compartment id where the service catalog exists.


        :param compartment_id: The compartment_id of this ServiceCatalogSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this ServiceCatalogSummary.
        The name of the service catalog.


        :return: The display_name of this ServiceCatalogSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this ServiceCatalogSummary.
        The name of the service catalog.


        :param display_name: The display_name of this ServiceCatalogSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this ServiceCatalogSummary.
        The date and time this service catalog was created, expressed in `RFC 3339`__
        timestamp format.

        Example: `2021-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this ServiceCatalogSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this ServiceCatalogSummary.
        The date and time this service catalog was created, expressed in `RFC 3339`__
        timestamp format.

        Example: `2021-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this ServiceCatalogSummary.
        :type: datetime
        """
        self._time_created = time_created

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Modified Work: Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
# Copyright 2008-2016 Andrey Petrov and contributors

from __future__ import absolute_import

import email.utils
import mimetypes
import re

from .packages import six


def guess_content_type(filename, default="application/octet-stream"):
    """
    Guess the "Content-Type" of a file.

    :param filename:
        The filename to guess the "Content-Type" of using :mod:`mimetypes`.
    :param default:
        If no "Content-Type" can be guessed, default to `default`.
    """
    if filename:
        return mimetypes.guess_type(filename)[0] or default
    return default


def format_header_param_rfc2231(name, value):
    """
    Helper function to format and quote a single header parameter using the
    strategy defined in RFC 2231.

    Particularly useful for header parameters which might contain
    non-ASCII values, like file names. This follows
    `RFC 2388 Section 4.4 <https://tools.ietf.org/html/rfc2388#section-4.4>`_.

    :param name:
        The name of the parameter, a string expected to be ASCII only.
    :param value:
        The value of the parameter, provided as ``bytes`` or `str``.
    :ret:
        An RFC-2231-formatted unicode string.
    """
    if isinstance(value, six.binary_type):
        value = value.decode("utf-8")

    if not any(ch in value for ch in '"\\\r\n'):
        result = u'%s="%s"' % (name, value)
        try:
            result.encode("ascii")
        except (UnicodeEncodeError, UnicodeDecodeError):
            pass
        else:
            return result

    if six.PY2:  # Python 2:
        value = value.encode("utf-8")

    # encode_rfc2231 accepts an encoded string and returns an ascii-encoded
    # string in Python 2 but accepts and returns unicode strings in Python 3
    value = email.utils.encode_rfc2231(value, "utf-8")
    value = "%s*=%s" % (name, value)

    if six.PY2:  # Python 2:
        value = value.decode("utf-8")

    return value


_HTML5_REPLACEMENTS = {
    u"\u0022": u"%22",
    # Replace "\" with "\\".
    u"\u005C": u"\u005C\u005C",
}

# All control characters from 0x00 to 0x1F *except* 0x1B.
_HTML5_REPLACEMENTS.update(
    {
        six.unichr(cc): u"%{:02X}".format(cc)
        for cc in range(0x00, 0x1F + 1)
        if cc not in (0x1B,)
    }
)


def _replace_multiple(value, needles_and_replacements):
    def replacer(match):
        return needles_and_replacements[match.group(0)]

    pattern = re.compile(
        r"|".join([re.escape(needle) for needle in needles_and_replacements.keys()])
    )

    result = pattern.sub(replacer, value)

    return result


def format_header_param_html5(name, value):
    """
    Helper function to format and quote a single header parameter using the
    HTML5 strategy.

    Particularly useful for header parameters which might contain
    non-ASCII values, like file names. This follows the `HTML5 Working Draft
    Section 4.10.22.7`_ and matches the behavior of curl and modern browsers.

    .. _HTML5 Working Draft Section 4.10.22.7:
        https://w3c.github.io/html/sec-forms.html#multipart-form-data

    :param name:
        The name of the parameter, a string expected to be ASCII only.
    :param value:
        The value of the parameter, provided as ``bytes`` or `str``.
    :ret:
        A unicode string, stripped of troublesome characters.
    """
    if isinstance(value, six.binary_type):
        value = value.decode("utf-8")

    value = _replace_multiple(value, _HTML5_REPLACEMENTS)

    return u'%s="%s"' % (name, value)


# For backwards-compatibility.
format_header_param = format_header_param_html5


class RequestField(object):
    """
    A data container for request body parameters.

    :param name:
        The name of this request field. Must be unicode.
    :param data:
        The data/value body.
    :param filename:
        An optional filename of the request field. Must be unicode.
    :param headers:
        An optional dict-like object of headers to initially use for the field.
    :param header_formatter:
        An optional callable that is used to encode and format the headers. By
        default, this is :func:`format_header_param_html5`.
    """

    def __init__(
        self,
        name,
        data,
        filename=None,
        headers=None,
        header_formatter=format_header_param_html5,
    ):
        self._name = name
        self._filename = filename
        self.data = data
        self.headers = {}
        if headers:
            self.headers = dict(headers)
        self.header_formatter = header_formatter

    @classmethod
    def from_tuples(cls, fieldname, value, header_formatter=format_header_param_html5):
        """
        A :class:`~urllib3.fields.RequestField` factory from old-style tuple parameters.

        Supports constructing :class:`~urllib3.fields.RequestField` from
        parameter of key/value strings AND key/filetuple. A filetuple is a
        (filename, data, MIME type) tuple where the MIME type is optional.
        For example::

            'foo': 'bar',
            'fakefile': ('foofile.txt', 'contents of foofile'),
            'realfile': ('barfile.txt', open('realfile').read()),
            'typedfile': ('bazfile.bin', open('bazfile').read(), 'image/jpeg'),
            'nonamefile': 'contents of nonamefile field',

        Field names and filenames must be unicode.
        """
        if isinstance(value, tuple):
            if len(value) == 3:
                filename, data, content_type = value
            else:
                filename, data = value
                content_type = guess_content_type(filename)
        else:
            filename = None
            content_type = None
            data = value

        request_param = cls(
            fieldname, data, filename=filename, header_formatter=header_formatter
        )
        request_param.make_multipart(content_type=content_type)

        return request_param

    def _render_part(self, name, value):
        """
        Overridable helper function to format a single header parameter. By
        default, this calls ``self.header_formatter``.

        :param name:
            The name of the parameter, a string expected to be ASCII only.
        :param value:
            The value of the parameter, provided as a unicode string.
        """

        return self.header_formatter(name, value)

    def _render_parts(self, header_parts):
        """
        Helper function to format and quote a single header.

        Useful for single headers that are composed of multiple items. E.g.,
        'Content-Disposition' fields.

        :param header_parts:
            A sequence of (k, v) tuples or a :class:`dict` of (k, v) to format
            as `k1="v1"; k2="v2"; ...`.
        """
        parts = []
        iterable = header_parts
        if isinstance(header_parts, dict):
            iterable = header_parts.items()

        for name, value in iterable:
            if value is not None:
                parts.append(self._render_part(name, value))

        return u"; ".join(parts)

    def render_headers(self):
        """
        Renders the headers for this request field.
        """
        lines = []

        sort_keys = ["Content-Disposition", "Content-Type", "Content-Location"]
        for sort_key in sort_keys:
            if self.headers.get(sort_key, False):
                lines.append(u"%s: %s" % (sort_key, self.headers[sort_key]))

        for header_name, header_value in self.headers.items():
            if header_name not in sort_keys:
                if header_value:
                    lines.append(u"%s: %s" % (header_name, header_value))

        lines.append(u"\r\n")
        return u"\r\n".join(lines)

    def make_multipart(
        self, content_disposition=None, content_type=None, content_location=None
    ):
        """
        Makes this request field into a multipart request field.

        This method overrides "Content-Disposition", "Content-Type" and
        "Content-Location" headers to the request parameter.

        :param content_type:
            The 'Content-Type' of the request body.
        :param content_location:
            The 'Content-Location' of the request body.

        """
        self.headers["Content-Disposition"] = content_disposition or u"form-data"
        self.headers["Content-Disposition"] += u"; ".join(
            [
                u"",
                self._render_parts(
                    ((u"name", self._name), (u"filename", self._filename))
                ),
            ]
        )
        self.headers["Content-Type"] = content_type
        self.headers["Content-Location"] = content_location



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LogAnalyticsSourceLabelCondition(object):
    """
    LogAnalyticsSourceLabelCondition
    """

    def __init__(self, **kwargs):
        """
        Initializes a new LogAnalyticsSourceLabelCondition object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param message:
            The value to assign to the message property of this LogAnalyticsSourceLabelCondition.
        :type message: str

        :param is_visible:
            The value to assign to the is_visible property of this LogAnalyticsSourceLabelCondition.
        :type is_visible: bool

        :param block_condition_field:
            The value to assign to the block_condition_field property of this LogAnalyticsSourceLabelCondition.
        :type block_condition_field: str

        :param block_condition_operator:
            The value to assign to the block_condition_operator property of this LogAnalyticsSourceLabelCondition.
        :type block_condition_operator: str

        :param block_condition_value:
            The value to assign to the block_condition_value property of this LogAnalyticsSourceLabelCondition.
        :type block_condition_value: str

        :param label_condition_value:
            The value to assign to the label_condition_value property of this LogAnalyticsSourceLabelCondition.
        :type label_condition_value: str

        :param label_condition_values:
            The value to assign to the label_condition_values property of this LogAnalyticsSourceLabelCondition.
        :type label_condition_values: list[str]

        :param content_example:
            The value to assign to the content_example property of this LogAnalyticsSourceLabelCondition.
        :type content_example: str

        :param is_enabled:
            The value to assign to the is_enabled property of this LogAnalyticsSourceLabelCondition.
        :type is_enabled: bool

        :param field_name:
            The value to assign to the field_name property of this LogAnalyticsSourceLabelCondition.
        :type field_name: str

        :param label_condition_id:
            The value to assign to the label_condition_id property of this LogAnalyticsSourceLabelCondition.
        :type label_condition_id: int

        :param is_system:
            The value to assign to the is_system property of this LogAnalyticsSourceLabelCondition.
        :type is_system: bool

        :param label_condition_operator:
            The value to assign to the label_condition_operator property of this LogAnalyticsSourceLabelCondition.
        :type label_condition_operator: str

        :param source_id:
            The value to assign to the source_id property of this LogAnalyticsSourceLabelCondition.
        :type source_id: int

        :param label_display_name:
            The value to assign to the label_display_name property of this LogAnalyticsSourceLabelCondition.
        :type label_display_name: str

        :param storage_field:
            The value to assign to the storage_field property of this LogAnalyticsSourceLabelCondition.
        :type storage_field: str

        :param label_name:
            The value to assign to the label_name property of this LogAnalyticsSourceLabelCondition.
        :type label_name: str

        :param is_inline_label_existing_in_database:
            The value to assign to the is_inline_label_existing_in_database property of this LogAnalyticsSourceLabelCondition.
        :type is_inline_label_existing_in_database: bool

        """
        self.swagger_types = {
            'message': 'str',
            'is_visible': 'bool',
            'block_condition_field': 'str',
            'block_condition_operator': 'str',
            'block_condition_value': 'str',
            'label_condition_value': 'str',
            'label_condition_values': 'list[str]',
            'content_example': 'str',
            'is_enabled': 'bool',
            'field_name': 'str',
            'label_condition_id': 'int',
            'is_system': 'bool',
            'label_condition_operator': 'str',
            'source_id': 'int',
            'label_display_name': 'str',
            'storage_field': 'str',
            'label_name': 'str',
            'is_inline_label_existing_in_database': 'bool'
        }

        self.attribute_map = {
            'message': 'message',
            'is_visible': 'isVisible',
            'block_condition_field': 'blockConditionField',
            'block_condition_operator': 'blockConditionOperator',
            'block_condition_value': 'blockConditionValue',
            'label_condition_value': 'labelConditionValue',
            'label_condition_values': 'labelConditionValues',
            'content_example': 'contentExample',
            'is_enabled': 'isEnabled',
            'field_name': 'fieldName',
            'label_condition_id': 'labelConditionId',
            'is_system': 'isSystem',
            'label_condition_operator': 'labelConditionOperator',
            'source_id': 'sourceId',
            'label_display_name': 'labelDisplayName',
            'storage_field': 'storageField',
            'label_name': 'labelName',
            'is_inline_label_existing_in_database': 'isInlineLabelExistingInDatabase'
        }

        self._message = None
        self._is_visible = None
        self._block_condition_field = None
        self._block_condition_operator = None
        self._block_condition_value = None
        self._label_condition_value = None
        self._label_condition_values = None
        self._content_example = None
        self._is_enabled = None
        self._field_name = None
        self._label_condition_id = None
        self._is_system = None
        self._label_condition_operator = None
        self._source_id = None
        self._label_display_name = None
        self._storage_field = None
        self._label_name = None
        self._is_inline_label_existing_in_database = None

    @property
    def message(self):
        """
        Gets the message of this LogAnalyticsSourceLabelCondition.
        The message.


        :return: The message of this LogAnalyticsSourceLabelCondition.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this LogAnalyticsSourceLabelCondition.
        The message.


        :param message: The message of this LogAnalyticsSourceLabelCondition.
        :type: str
        """
        self._message = message

    @property
    def is_visible(self):
        """
        Gets the is_visible of this LogAnalyticsSourceLabelCondition.
        A flag indicating whether or not the label condition is visible.


        :return: The is_visible of this LogAnalyticsSourceLabelCondition.
        :rtype: bool
        """
        return self._is_visible

    @is_visible.setter
    def is_visible(self, is_visible):
        """
        Sets the is_visible of this LogAnalyticsSourceLabelCondition.
        A flag indicating whether or not the label condition is visible.


        :param is_visible: The is_visible of this LogAnalyticsSourceLabelCondition.
        :type: bool
        """
        self._is_visible = is_visible

    @property
    def block_condition_field(self):
        """
        Gets the block_condition_field of this LogAnalyticsSourceLabelCondition.
        The block condition field.


        :return: The block_condition_field of this LogAnalyticsSourceLabelCondition.
        :rtype: str
        """
        return self._block_condition_field

    @block_condition_field.setter
    def block_condition_field(self, block_condition_field):
        """
        Sets the block_condition_field of this LogAnalyticsSourceLabelCondition.
        The block condition field.


        :param block_condition_field: The block_condition_field of this LogAnalyticsSourceLabelCondition.
        :type: str
        """
        self._block_condition_field = block_condition_field

    @property
    def block_condition_operator(self):
        """
        Gets the block_condition_operator of this LogAnalyticsSourceLabelCondition.
        The block condition operator.


        :return: The block_condition_operator of this LogAnalyticsSourceLabelCondition.
        :rtype: str
        """
        return self._block_condition_operator

    @block_condition_operator.setter
    def block_condition_operator(self, block_condition_operator):
        """
        Sets the block_condition_operator of this LogAnalyticsSourceLabelCondition.
        The block condition operator.


        :param block_condition_operator: The block_condition_operator of this LogAnalyticsSourceLabelCondition.
        :type: str
        """
        self._block_condition_operator = block_condition_operator

    @property
    def block_condition_value(self):
        """
        Gets the block_condition_value of this LogAnalyticsSourceLabelCondition.
        The block condition value.


        :return: The block_condition_value of this LogAnalyticsSourceLabelCondition.
        :rtype: str
        """
        return self._block_condition_value

    @block_condition_value.setter
    def block_condition_value(self, block_condition_value):
        """
        Sets the block_condition_value of this LogAnalyticsSourceLabelCondition.
        The block condition value.


        :param block_condition_value: The block_condition_value of this LogAnalyticsSourceLabelCondition.
        :type: str
        """
        self._block_condition_value = block_condition_value

    @property
    def label_condition_value(self):
        """
        Gets the label_condition_value of this LogAnalyticsSourceLabelCondition.
        The condition value.


        :return: The label_condition_value of this LogAnalyticsSourceLabelCondition.
        :rtype: str
        """
        return self._label_condition_value

    @label_condition_value.setter
    def label_condition_value(self, label_condition_value):
        """
        Sets the label_condition_value of this LogAnalyticsSourceLabelCondition.
        The condition value.


        :param label_condition_value: The label_condition_value of this LogAnalyticsSourceLabelCondition.
        :type: str
        """
        self._label_condition_value = label_condition_value

    @property
    def label_condition_values(self):
        """
        Gets the label_condition_values of this LogAnalyticsSourceLabelCondition.
        A list of condition values.


        :return: The label_condition_values of this LogAnalyticsSourceLabelCondition.
        :rtype: list[str]
        """
        return self._label_condition_values

    @label_condition_values.setter
    def label_condition_values(self, label_condition_values):
        """
        Sets the label_condition_values of this LogAnalyticsSourceLabelCondition.
        A list of condition values.


        :param label_condition_values: The label_condition_values of this LogAnalyticsSourceLabelCondition.
        :type: list[str]
        """
        self._label_condition_values = label_condition_values

    @property
    def content_example(self):
        """
        Gets the content_example of this LogAnalyticsSourceLabelCondition.
        The content example.


        :return: The content_example of this LogAnalyticsSourceLabelCondition.
        :rtype: str
        """
        return self._content_example

    @content_example.setter
    def content_example(self, content_example):
        """
        Sets the content_example of this LogAnalyticsSourceLabelCondition.
        The content example.


        :param content_example: The content_example of this LogAnalyticsSourceLabelCondition.
        :type: str
        """
        self._content_example = content_example

    @property
    def is_enabled(self):
        """
        Gets the is_enabled of this LogAnalyticsSourceLabelCondition.
        A flag inidcating whether or not the condition is enabled.


        :return: The is_enabled of this LogAnalyticsSourceLabelCondition.
        :rtype: bool
        """
        return self._is_enabled

    @is_enabled.setter
    def is_enabled(self, is_enabled):
        """
        Sets the is_enabled of this LogAnalyticsSourceLabelCondition.
        A flag inidcating whether or not the condition is enabled.


        :param is_enabled: The is_enabled of this LogAnalyticsSourceLabelCondition.
        :type: bool
        """
        self._is_enabled = is_enabled

    @property
    def field_name(self):
        """
        Gets the field_name of this LogAnalyticsSourceLabelCondition.
        The internal field name.


        :return: The field_name of this LogAnalyticsSourceLabelCondition.
        :rtype: str
        """
        return self._field_name

    @field_name.setter
    def field_name(self, field_name):
        """
        Sets the field_name of this LogAnalyticsSourceLabelCondition.
        The internal field name.


        :param field_name: The field_name of this LogAnalyticsSourceLabelCondition.
        :type: str
        """
        self._field_name = field_name

    @property
    def label_condition_id(self):
        """
        Gets the label_condition_id of this LogAnalyticsSourceLabelCondition.
        The unique identifier of the condition.


        :return: The label_condition_id of this LogAnalyticsSourceLabelCondition.
        :rtype: int
        """
        return self._label_condition_id

    @label_condition_id.setter
    def label_condition_id(self, label_condition_id):
        """
        Sets the label_condition_id of this LogAnalyticsSourceLabelCondition.
        The unique identifier of the condition.


        :param label_condition_id: The label_condition_id of this LogAnalyticsSourceLabelCondition.
        :type: int
        """
        self._label_condition_id = label_condition_id

    @property
    def is_system(self):
        """
        Gets the is_system of this LogAnalyticsSourceLabelCondition.
        The system flag.  A value of false denotes a custom, or user
        defined object.  A value of true denotes a built in object.


        :return: The is_system of this LogAnalyticsSourceLabelCondition.
        :rtype: bool
        """
        return self._is_system

    @is_system.setter
    def is_system(self, is_system):
        """
        Sets the is_system of this LogAnalyticsSourceLabelCondition.
        The system flag.  A value of false denotes a custom, or user
        defined object.  A value of true denotes a built in object.


        :param is_system: The is_system of this LogAnalyticsSourceLabelCondition.
        :type: bool
        """
        self._is_system = is_system

    @property
    def label_condition_operator(self):
        """
        Gets the label_condition_operator of this LogAnalyticsSourceLabelCondition.
        The condition operator.


        :return: The label_condition_operator of this LogAnalyticsSourceLabelCondition.
        :rtype: str
        """
        return self._label_condition_operator

    @label_condition_operator.setter
    def label_condition_operator(self, label_condition_operator):
        """
        Sets the label_condition_operator of this LogAnalyticsSourceLabelCondition.
        The condition operator.


        :param label_condition_operator: The label_condition_operator of this LogAnalyticsSourceLabelCondition.
        :type: str
        """
        self._label_condition_operator = label_condition_operator

    @property
    def source_id(self):
        """
        Gets the source_id of this LogAnalyticsSourceLabelCondition.
        The unique identifier of the source.


        :return: The source_id of this LogAnalyticsSourceLabelCondition.
        :rtype: int
        """
        return self._source_id

    @source_id.setter
    def source_id(self, source_id):
        """
        Sets the source_id of this LogAnalyticsSourceLabelCondition.
        The unique identifier of the source.


        :param source_id: The source_id of this LogAnalyticsSourceLabelCondition.
        :type: int
        """
        self._source_id = source_id

    @property
    def label_display_name(self):
        """
        Gets the label_display_name of this LogAnalyticsSourceLabelCondition.
        The label display name.


        :return: The label_display_name of this LogAnalyticsSourceLabelCondition.
        :rtype: str
        """
        return self._label_display_name

    @label_display_name.setter
    def label_display_name(self, label_display_name):
        """
        Sets the label_display_name of this LogAnalyticsSourceLabelCondition.
        The label display name.


        :param label_display_name: The label_display_name of this LogAnalyticsSourceLabelCondition.
        :type: str
        """
        self._label_display_name = label_display_name

    @property
    def storage_field(self):
        """
        Gets the storage_field of this LogAnalyticsSourceLabelCondition.
        The label storage field.


        :return: The storage_field of this LogAnalyticsSourceLabelCondition.
        :rtype: str
        """
        return self._storage_field

    @storage_field.setter
    def storage_field(self, storage_field):
        """
        Sets the storage_field of this LogAnalyticsSourceLabelCondition.
        The label storage field.


        :param storage_field: The storage_field of this LogAnalyticsSourceLabelCondition.
        :type: str
        """
        self._storage_field = storage_field

    @property
    def label_name(self):
        """
        Gets the label_name of this LogAnalyticsSourceLabelCondition.
        The label name.


        :return: The label_name of this LogAnalyticsSourceLabelCondition.
        :rtype: str
        """
        return self._label_name

    @label_name.setter
    def label_name(self, label_name):
        """
        Sets the label_name of this LogAnalyticsSourceLabelCondition.
        The label name.


        :param label_name: The label_name of this LogAnalyticsSourceLabelCondition.
        :type: str
        """
        self._label_name = label_name

    @property
    def is_inline_label_existing_in_database(self):
        """
        Gets the is_inline_label_existing_in_database of this LogAnalyticsSourceLabelCondition.
        A flag indicating whether or not the inline label exists in the database.


        :return: The is_inline_label_existing_in_database of this LogAnalyticsSourceLabelCondition.
        :rtype: bool
        """
        return self._is_inline_label_existing_in_database

    @is_inline_label_existing_in_database.setter
    def is_inline_label_existing_in_database(self, is_inline_label_existing_in_database):
        """
        Sets the is_inline_label_existing_in_database of this LogAnalyticsSourceLabelCondition.
        A flag indicating whether or not the inline label exists in the database.


        :param is_inline_label_existing_in_database: The is_inline_label_existing_in_database of this LogAnalyticsSourceLabelCondition.
        :type: bool
        """
        self._is_inline_label_existing_in_database = is_inline_label_existing_in_database

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .host_insight_summary import HostInsightSummary
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class MacsManagedExternalHostInsightSummary(HostInsightSummary):
    """
    Summary of a MACS-managed external host insight resource.
    """

    #: A constant which can be used with the platform_type property of a MacsManagedExternalHostInsightSummary.
    #: This constant has a value of "LINUX"
    PLATFORM_TYPE_LINUX = "LINUX"

    def __init__(self, **kwargs):
        """
        Initializes a new MacsManagedExternalHostInsightSummary object with values from keyword arguments. The default value of the :py:attr:`~oci.opsi.models.MacsManagedExternalHostInsightSummary.entity_source` attribute
        of this class is ``MACS_MANAGED_EXTERNAL_HOST`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param entity_source:
            The value to assign to the entity_source property of this MacsManagedExternalHostInsightSummary.
            Allowed values for this property are: "MACS_MANAGED_EXTERNAL_HOST", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type entity_source: str

        :param id:
            The value to assign to the id property of this MacsManagedExternalHostInsightSummary.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this MacsManagedExternalHostInsightSummary.
        :type compartment_id: str

        :param host_name:
            The value to assign to the host_name property of this MacsManagedExternalHostInsightSummary.
        :type host_name: str

        :param host_display_name:
            The value to assign to the host_display_name property of this MacsManagedExternalHostInsightSummary.
        :type host_display_name: str

        :param host_type:
            The value to assign to the host_type property of this MacsManagedExternalHostInsightSummary.
        :type host_type: str

        :param processor_count:
            The value to assign to the processor_count property of this MacsManagedExternalHostInsightSummary.
        :type processor_count: int

        :param freeform_tags:
            The value to assign to the freeform_tags property of this MacsManagedExternalHostInsightSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this MacsManagedExternalHostInsightSummary.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this MacsManagedExternalHostInsightSummary.
        :type system_tags: dict(str, dict(str, object))

        :param status:
            The value to assign to the status property of this MacsManagedExternalHostInsightSummary.
            Allowed values for this property are: "DISABLED", "ENABLED", "TERMINATED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        :param time_created:
            The value to assign to the time_created property of this MacsManagedExternalHostInsightSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this MacsManagedExternalHostInsightSummary.
        :type time_updated: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this MacsManagedExternalHostInsightSummary.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", "NEEDS_ATTENTION", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this MacsManagedExternalHostInsightSummary.
        :type lifecycle_details: str

        :param management_agent_id:
            The value to assign to the management_agent_id property of this MacsManagedExternalHostInsightSummary.
        :type management_agent_id: str

        :param platform_type:
            The value to assign to the platform_type property of this MacsManagedExternalHostInsightSummary.
            Allowed values for this property are: "LINUX", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type platform_type: str

        """
        self.swagger_types = {
            'entity_source': 'str',
            'id': 'str',
            'compartment_id': 'str',
            'host_name': 'str',
            'host_display_name': 'str',
            'host_type': 'str',
            'processor_count': 'int',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))',
            'status': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'management_agent_id': 'str',
            'platform_type': 'str'
        }

        self.attribute_map = {
            'entity_source': 'entitySource',
            'id': 'id',
            'compartment_id': 'compartmentId',
            'host_name': 'hostName',
            'host_display_name': 'hostDisplayName',
            'host_type': 'hostType',
            'processor_count': 'processorCount',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags',
            'status': 'status',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'management_agent_id': 'managementAgentId',
            'platform_type': 'platformType'
        }

        self._entity_source = None
        self._id = None
        self._compartment_id = None
        self._host_name = None
        self._host_display_name = None
        self._host_type = None
        self._processor_count = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None
        self._status = None
        self._time_created = None
        self._time_updated = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._management_agent_id = None
        self._platform_type = None
        self._entity_source = 'MACS_MANAGED_EXTERNAL_HOST'

    @property
    def management_agent_id(self):
        """
        **[Required]** Gets the management_agent_id of this MacsManagedExternalHostInsightSummary.
        The `OCID`__ of the Management Agent

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The management_agent_id of this MacsManagedExternalHostInsightSummary.
        :rtype: str
        """
        return self._management_agent_id

    @management_agent_id.setter
    def management_agent_id(self, management_agent_id):
        """
        Sets the management_agent_id of this MacsManagedExternalHostInsightSummary.
        The `OCID`__ of the Management Agent

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param management_agent_id: The management_agent_id of this MacsManagedExternalHostInsightSummary.
        :type: str
        """
        self._management_agent_id = management_agent_id

    @property
    def platform_type(self):
        """
        Gets the platform_type of this MacsManagedExternalHostInsightSummary.
        Platform type.

        Allowed values for this property are: "LINUX", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The platform_type of this MacsManagedExternalHostInsightSummary.
        :rtype: str
        """
        return self._platform_type

    @platform_type.setter
    def platform_type(self, platform_type):
        """
        Sets the platform_type of this MacsManagedExternalHostInsightSummary.
        Platform type.


        :param platform_type: The platform_type of this MacsManagedExternalHostInsightSummary.
        :type: str
        """
        allowed_values = ["LINUX"]
        if not value_allowed_none_or_none_sentinel(platform_type, allowed_values):
            platform_type = 'UNKNOWN_ENUM_VALUE'
        self._platform_type = platform_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Upload(object):
    """
    Upload is a container that can be used to put all the relevant and related on-demand upload based log files together.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Upload object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param reference:
            The value to assign to the reference property of this Upload.
        :type reference: str

        :param name:
            The value to assign to the name property of this Upload.
        :type name: str

        :param time_created:
            The value to assign to the time_created property of this Upload.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this Upload.
        :type time_updated: datetime

        :param time_earliest_log_entry:
            The value to assign to the time_earliest_log_entry property of this Upload.
        :type time_earliest_log_entry: datetime

        :param time_latest_log_entry:
            The value to assign to the time_latest_log_entry property of this Upload.
        :type time_latest_log_entry: datetime

        :param warnings_count:
            The value to assign to the warnings_count property of this Upload.
        :type warnings_count: int

        """
        self.swagger_types = {
            'reference': 'str',
            'name': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'time_earliest_log_entry': 'datetime',
            'time_latest_log_entry': 'datetime',
            'warnings_count': 'int'
        }

        self.attribute_map = {
            'reference': 'reference',
            'name': 'name',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'time_earliest_log_entry': 'timeEarliestLogEntry',
            'time_latest_log_entry': 'timeLatestLogEntry',
            'warnings_count': 'warningsCount'
        }

        self._reference = None
        self._name = None
        self._time_created = None
        self._time_updated = None
        self._time_earliest_log_entry = None
        self._time_latest_log_entry = None
        self._warnings_count = None

    @property
    def reference(self):
        """
        **[Required]** Gets the reference of this Upload.
        Unique internal identifier to refer the upload container.


        :return: The reference of this Upload.
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """
        Sets the reference of this Upload.
        Unique internal identifier to refer the upload container.


        :param reference: The reference of this Upload.
        :type: str
        """
        self._reference = reference

    @property
    def name(self):
        """
        **[Required]** Gets the name of this Upload.
        The name of the upload container.


        :return: The name of this Upload.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Upload.
        The name of the upload container.


        :param name: The name of this Upload.
        :type: str
        """
        self._name = name

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this Upload.
        The time when this upload container is created. An RFC3339 formatted datetime string.


        :return: The time_created of this Upload.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this Upload.
        The time when this upload container is created. An RFC3339 formatted datetime string.


        :param time_created: The time_created of this Upload.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this Upload.
        The latest time when this upload container is modified. An RFC3339 formatted datetime string.


        :return: The time_updated of this Upload.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this Upload.
        The latest time when this upload container is modified. An RFC3339 formatted datetime string.


        :param time_updated: The time_updated of this Upload.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def time_earliest_log_entry(self):
        """
        Gets the time_earliest_log_entry of this Upload.
        This time represents the earliest time of the log entry in this container. An RFC3339 formatted datetime string.


        :return: The time_earliest_log_entry of this Upload.
        :rtype: datetime
        """
        return self._time_earliest_log_entry

    @time_earliest_log_entry.setter
    def time_earliest_log_entry(self, time_earliest_log_entry):
        """
        Sets the time_earliest_log_entry of this Upload.
        This time represents the earliest time of the log entry in this container. An RFC3339 formatted datetime string.


        :param time_earliest_log_entry: The time_earliest_log_entry of this Upload.
        :type: datetime
        """
        self._time_earliest_log_entry = time_earliest_log_entry

    @property
    def time_latest_log_entry(self):
        """
        Gets the time_latest_log_entry of this Upload.
        This time represents the latest time of the log entry in this container. An RFC3339 formatted datetime string.


        :return: The time_latest_log_entry of this Upload.
        :rtype: datetime
        """
        return self._time_latest_log_entry

    @time_latest_log_entry.setter
    def time_latest_log_entry(self, time_latest_log_entry):
        """
        Sets the time_latest_log_entry of this Upload.
        This time represents the latest time of the log entry in this container. An RFC3339 formatted datetime string.


        :param time_latest_log_entry: The time_latest_log_entry of this Upload.
        :type: datetime
        """
        self._time_latest_log_entry = time_latest_log_entry

    @property
    def warnings_count(self):
        """
        Gets the warnings_count of this Upload.
        Number of warnings associated to the upload.


        :return: The warnings_count of this Upload.
        :rtype: int
        """
        return self._warnings_count

    @warnings_count.setter
    def warnings_count(self, warnings_count):
        """
        Sets the warnings_count of this Upload.
        Number of warnings associated to the upload.


        :param warnings_count: The warnings_count of this Upload.
        :type: int
        """
        self._warnings_count = warnings_count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .activate_target_database_details import ActivateTargetDatabaseDetails
from .autonomous_database_details import AutonomousDatabaseDetails
from .change_data_safe_private_endpoint_compartment_details import ChangeDataSafePrivateEndpointCompartmentDetails
from .change_on_prem_connector_compartment_details import ChangeOnPremConnectorCompartmentDetails
from .change_security_assessment_compartment_details import ChangeSecurityAssessmentCompartmentDetails
from .change_target_database_compartment_details import ChangeTargetDatabaseCompartmentDetails
from .change_user_assessment_compartment_details import ChangeUserAssessmentCompartmentDetails
from .compare_security_assessment_details import CompareSecurityAssessmentDetails
from .compare_user_assessment_details import CompareUserAssessmentDetails
from .connection_option import ConnectionOption
from .create_data_safe_private_endpoint_details import CreateDataSafePrivateEndpointDetails
from .create_on_prem_connector_details import CreateOnPremConnectorDetails
from .create_security_assessment_details import CreateSecurityAssessmentDetails
from .create_target_database_details import CreateTargetDatabaseDetails
from .create_user_assessment_details import CreateUserAssessmentDetails
from .credentials import Credentials
from .data_safe_configuration import DataSafeConfiguration
from .data_safe_private_endpoint import DataSafePrivateEndpoint
from .data_safe_private_endpoint_summary import DataSafePrivateEndpointSummary
from .database_cloud_service_details import DatabaseCloudServiceDetails
from .database_details import DatabaseDetails
from .diffs import Diffs
from .download_security_assessment_report_details import DownloadSecurityAssessmentReportDetails
from .download_user_assessment_report_details import DownloadUserAssessmentReportDetails
from .enable_data_safe_configuration_details import EnableDataSafeConfigurationDetails
from .finding import Finding
from .finding_summary import FindingSummary
from .generate_on_prem_connector_configuration_details import GenerateOnPremConnectorConfigurationDetails
from .generate_security_assessment_report_details import GenerateSecurityAssessmentReportDetails
from .generate_user_assessment_report_details import GenerateUserAssessmentReportDetails
from .grant_summary import GrantSummary
from .initialization_parameter import InitializationParameter
from .installed_database_details import InstalledDatabaseDetails
from .on_prem_connector import OnPremConnector
from .on_prem_connector_summary import OnPremConnectorSummary
from .on_premise_connector import OnPremiseConnector
from .private_endpoint import PrivateEndpoint
from .profile_details import ProfileDetails
from .references import References
from .run_security_assessment_details import RunSecurityAssessmentDetails
from .run_user_assessment_details import RunUserAssessmentDetails
from .section_statistics import SectionStatistics
from .security_assessment import SecurityAssessment
from .security_assessment_base_line_details import SecurityAssessmentBaseLineDetails
from .security_assessment_comparison import SecurityAssessmentComparison
from .security_assessment_comparison_per_target import SecurityAssessmentComparisonPerTarget
from .security_assessment_statistics import SecurityAssessmentStatistics
from .security_assessment_summary import SecurityAssessmentSummary
from .target_database import TargetDatabase
from .target_database_summary import TargetDatabaseSummary
from .tls_config import TlsConfig
from .update_data_safe_private_endpoint_details import UpdateDataSafePrivateEndpointDetails
from .update_on_prem_connector_details import UpdateOnPremConnectorDetails
from .update_on_prem_connector_wallet_details import UpdateOnPremConnectorWalletDetails
from .update_security_assessment_details import UpdateSecurityAssessmentDetails
from .update_target_database_details import UpdateTargetDatabaseDetails
from .update_user_assessment_details import UpdateUserAssessmentDetails
from .user_aggregation import UserAggregation
from .user_assessment import UserAssessment
from .user_assessment_base_line_details import UserAssessmentBaseLineDetails
from .user_assessment_comparison import UserAssessmentComparison
from .user_assessment_summary import UserAssessmentSummary
from .user_details import UserDetails
from .user_summary import UserSummary
from .work_request import WorkRequest
from .work_request_error import WorkRequestError
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_resource import WorkRequestResource
from .work_request_summary import WorkRequestSummary

# Maps type names to classes for data_safe services.
data_safe_type_mapping = {
    "ActivateTargetDatabaseDetails": ActivateTargetDatabaseDetails,
    "AutonomousDatabaseDetails": AutonomousDatabaseDetails,
    "ChangeDataSafePrivateEndpointCompartmentDetails": ChangeDataSafePrivateEndpointCompartmentDetails,
    "ChangeOnPremConnectorCompartmentDetails": ChangeOnPremConnectorCompartmentDetails,
    "ChangeSecurityAssessmentCompartmentDetails": ChangeSecurityAssessmentCompartmentDetails,
    "ChangeTargetDatabaseCompartmentDetails": ChangeTargetDatabaseCompartmentDetails,
    "ChangeUserAssessmentCompartmentDetails": ChangeUserAssessmentCompartmentDetails,
    "CompareSecurityAssessmentDetails": CompareSecurityAssessmentDetails,
    "CompareUserAssessmentDetails": CompareUserAssessmentDetails,
    "ConnectionOption": ConnectionOption,
    "CreateDataSafePrivateEndpointDetails": CreateDataSafePrivateEndpointDetails,
    "CreateOnPremConnectorDetails": CreateOnPremConnectorDetails,
    "CreateSecurityAssessmentDetails": CreateSecurityAssessmentDetails,
    "CreateTargetDatabaseDetails": CreateTargetDatabaseDetails,
    "CreateUserAssessmentDetails": CreateUserAssessmentDetails,
    "Credentials": Credentials,
    "DataSafeConfiguration": DataSafeConfiguration,
    "DataSafePrivateEndpoint": DataSafePrivateEndpoint,
    "DataSafePrivateEndpointSummary": DataSafePrivateEndpointSummary,
    "DatabaseCloudServiceDetails": DatabaseCloudServiceDetails,
    "DatabaseDetails": DatabaseDetails,
    "Diffs": Diffs,
    "DownloadSecurityAssessmentReportDetails": DownloadSecurityAssessmentReportDetails,
    "DownloadUserAssessmentReportDetails": DownloadUserAssessmentReportDetails,
    "EnableDataSafeConfigurationDetails": EnableDataSafeConfigurationDetails,
    "Finding": Finding,
    "FindingSummary": FindingSummary,
    "GenerateOnPremConnectorConfigurationDetails": GenerateOnPremConnectorConfigurationDetails,
    "GenerateSecurityAssessmentReportDetails": GenerateSecurityAssessmentReportDetails,
    "GenerateUserAssessmentReportDetails": GenerateUserAssessmentReportDetails,
    "GrantSummary": GrantSummary,
    "InitializationParameter": InitializationParameter,
    "InstalledDatabaseDetails": InstalledDatabaseDetails,
    "OnPremConnector": OnPremConnector,
    "OnPremConnectorSummary": OnPremConnectorSummary,
    "OnPremiseConnector": OnPremiseConnector,
    "PrivateEndpoint": PrivateEndpoint,
    "ProfileDetails": ProfileDetails,
    "References": References,
    "RunSecurityAssessmentDetails": RunSecurityAssessmentDetails,
    "RunUserAssessmentDetails": RunUserAssessmentDetails,
    "SectionStatistics": SectionStatistics,
    "SecurityAssessment": SecurityAssessment,
    "SecurityAssessmentBaseLineDetails": SecurityAssessmentBaseLineDetails,
    "SecurityAssessmentComparison": SecurityAssessmentComparison,
    "SecurityAssessmentComparisonPerTarget": SecurityAssessmentComparisonPerTarget,
    "SecurityAssessmentStatistics": SecurityAssessmentStatistics,
    "SecurityAssessmentSummary": SecurityAssessmentSummary,
    "TargetDatabase": TargetDatabase,
    "TargetDatabaseSummary": TargetDatabaseSummary,
    "TlsConfig": TlsConfig,
    "UpdateDataSafePrivateEndpointDetails": UpdateDataSafePrivateEndpointDetails,
    "UpdateOnPremConnectorDetails": UpdateOnPremConnectorDetails,
    "UpdateOnPremConnectorWalletDetails": UpdateOnPremConnectorWalletDetails,
    "UpdateSecurityAssessmentDetails": UpdateSecurityAssessmentDetails,
    "UpdateTargetDatabaseDetails": UpdateTargetDatabaseDetails,
    "UpdateUserAssessmentDetails": UpdateUserAssessmentDetails,
    "UserAggregation": UserAggregation,
    "UserAssessment": UserAssessment,
    "UserAssessmentBaseLineDetails": UserAssessmentBaseLineDetails,
    "UserAssessmentComparison": UserAssessmentComparison,
    "UserAssessmentSummary": UserAssessmentSummary,
    "UserDetails": UserDetails,
    "UserSummary": UserSummary,
    "WorkRequest": WorkRequest,
    "WorkRequestError": WorkRequestError,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestSummary": WorkRequestSummary
}



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PlatformConfig(object):
    """
    The platform configuration for the instance.
    """

    #: A constant which can be used with the type property of a PlatformConfig.
    #: This constant has a value of "AMD_MILAN_BM"
    TYPE_AMD_MILAN_BM = "AMD_MILAN_BM"

    #: A constant which can be used with the type property of a PlatformConfig.
    #: This constant has a value of "AMD_ROME_BM"
    TYPE_AMD_ROME_BM = "AMD_ROME_BM"

    #: A constant which can be used with the type property of a PlatformConfig.
    #: This constant has a value of "INTEL_SKYLAKE_BM"
    TYPE_INTEL_SKYLAKE_BM = "INTEL_SKYLAKE_BM"

    #: A constant which can be used with the type property of a PlatformConfig.
    #: This constant has a value of "AMD_VM"
    TYPE_AMD_VM = "AMD_VM"

    #: A constant which can be used with the type property of a PlatformConfig.
    #: This constant has a value of "INTEL_VM"
    TYPE_INTEL_VM = "INTEL_VM"

    def __init__(self, **kwargs):
        """
        Initializes a new PlatformConfig object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.core.models.AmdMilanBmPlatformConfig`
        * :class:`~oci.core.models.AmdRomeBmPlatformConfig`
        * :class:`~oci.core.models.IntelSkylakeBmPlatformConfig`
        * :class:`~oci.core.models.AmdVmPlatformConfig`
        * :class:`~oci.core.models.IntelVmPlatformConfig`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this PlatformConfig.
            Allowed values for this property are: "AMD_MILAN_BM", "AMD_ROME_BM", "INTEL_SKYLAKE_BM", "AMD_VM", "INTEL_VM", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        :param is_secure_boot_enabled:
            The value to assign to the is_secure_boot_enabled property of this PlatformConfig.
        :type is_secure_boot_enabled: bool

        :param is_trusted_platform_module_enabled:
            The value to assign to the is_trusted_platform_module_enabled property of this PlatformConfig.
        :type is_trusted_platform_module_enabled: bool

        :param is_measured_boot_enabled:
            The value to assign to the is_measured_boot_enabled property of this PlatformConfig.
        :type is_measured_boot_enabled: bool

        """
        self.swagger_types = {
            'type': 'str',
            'is_secure_boot_enabled': 'bool',
            'is_trusted_platform_module_enabled': 'bool',
            'is_measured_boot_enabled': 'bool'
        }

        self.attribute_map = {
            'type': 'type',
            'is_secure_boot_enabled': 'isSecureBootEnabled',
            'is_trusted_platform_module_enabled': 'isTrustedPlatformModuleEnabled',
            'is_measured_boot_enabled': 'isMeasuredBootEnabled'
        }

        self._type = None
        self._is_secure_boot_enabled = None
        self._is_trusted_platform_module_enabled = None
        self._is_measured_boot_enabled = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['type']

        if type == 'AMD_MILAN_BM':
            return 'AmdMilanBmPlatformConfig'

        if type == 'AMD_ROME_BM':
            return 'AmdRomeBmPlatformConfig'

        if type == 'INTEL_SKYLAKE_BM':
            return 'IntelSkylakeBmPlatformConfig'

        if type == 'AMD_VM':
            return 'AmdVmPlatformConfig'

        if type == 'INTEL_VM':
            return 'IntelVmPlatformConfig'
        else:
            return 'PlatformConfig'

    @property
    def type(self):
        """
        **[Required]** Gets the type of this PlatformConfig.
        The type of platform being configured.

        Allowed values for this property are: "AMD_MILAN_BM", "AMD_ROME_BM", "INTEL_SKYLAKE_BM", "AMD_VM", "INTEL_VM", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The type of this PlatformConfig.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this PlatformConfig.
        The type of platform being configured.


        :param type: The type of this PlatformConfig.
        :type: str
        """
        allowed_values = ["AMD_MILAN_BM", "AMD_ROME_BM", "INTEL_SKYLAKE_BM", "AMD_VM", "INTEL_VM"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            type = 'UNKNOWN_ENUM_VALUE'
        self._type = type

    @property
    def is_secure_boot_enabled(self):
        """
        Gets the is_secure_boot_enabled of this PlatformConfig.
        Whether Secure Boot is enabled on the instance.


        :return: The is_secure_boot_enabled of this PlatformConfig.
        :rtype: bool
        """
        return self._is_secure_boot_enabled

    @is_secure_boot_enabled.setter
    def is_secure_boot_enabled(self, is_secure_boot_enabled):
        """
        Sets the is_secure_boot_enabled of this PlatformConfig.
        Whether Secure Boot is enabled on the instance.


        :param is_secure_boot_enabled: The is_secure_boot_enabled of this PlatformConfig.
        :type: bool
        """
        self._is_secure_boot_enabled = is_secure_boot_enabled

    @property
    def is_trusted_platform_module_enabled(self):
        """
        Gets the is_trusted_platform_module_enabled of this PlatformConfig.
        Whether the Trusted Platform Module (TPM) is enabled on the instance.


        :return: The is_trusted_platform_module_enabled of this PlatformConfig.
        :rtype: bool
        """
        return self._is_trusted_platform_module_enabled

    @is_trusted_platform_module_enabled.setter
    def is_trusted_platform_module_enabled(self, is_trusted_platform_module_enabled):
        """
        Sets the is_trusted_platform_module_enabled of this PlatformConfig.
        Whether the Trusted Platform Module (TPM) is enabled on the instance.


        :param is_trusted_platform_module_enabled: The is_trusted_platform_module_enabled of this PlatformConfig.
        :type: bool
        """
        self._is_trusted_platform_module_enabled = is_trusted_platform_module_enabled

    @property
    def is_measured_boot_enabled(self):
        """
        Gets the is_measured_boot_enabled of this PlatformConfig.
        Whether the Measured Boot feature is enabled on the instance.


        :return: The is_measured_boot_enabled of this PlatformConfig.
        :rtype: bool
        """
        return self._is_measured_boot_enabled

    @is_measured_boot_enabled.setter
    def is_measured_boot_enabled(self, is_measured_boot_enabled):
        """
        Sets the is_measured_boot_enabled of this PlatformConfig.
        Whether the Measured Boot feature is enabled on the instance.


        :param is_measured_boot_enabled: The is_measured_boot_enabled of this PlatformConfig.
        :type: bool
        """
        self._is_measured_boot_enabled = is_measured_boot_enabled

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .event import Event
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class KernelCrashEvent(Event):
    """
    Information about a Kernel Crash.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new KernelCrashEvent object with values from keyword arguments. The default value of the :py:attr:`~oci.os_management.models.KernelCrashEvent.event_type` attribute
        of this class is ``KERNEL_CRASH`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this KernelCrashEvent.
        :type id: str

        :param instance_id:
            The value to assign to the instance_id property of this KernelCrashEvent.
        :type instance_id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this KernelCrashEvent.
        :type compartment_id: str

        :param tenancy_id:
            The value to assign to the tenancy_id property of this KernelCrashEvent.
        :type tenancy_id: str

        :param summary:
            The value to assign to the summary property of this KernelCrashEvent.
        :type summary: str

        :param timestamp:
            The value to assign to the timestamp property of this KernelCrashEvent.
        :type timestamp: datetime

        :param event_fingerprint:
            The value to assign to the event_fingerprint property of this KernelCrashEvent.
        :type event_fingerprint: str

        :param count:
            The value to assign to the count property of this KernelCrashEvent.
        :type count: int

        :param event_type:
            The value to assign to the event_type property of this KernelCrashEvent.
            Allowed values for this property are: "KERNEL_OOPS", "KERNEL_CRASH", "CRASH", "EXPLOIT_ATTEMPT", "COMPLIANCE", "TUNING_SUGGESTION", "TUNING_APPLIED", "SECURITY", "ERROR", "WARNING"
        :type event_type: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this KernelCrashEvent.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this KernelCrashEvent.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this KernelCrashEvent.
        :type system_tags: dict(str, dict(str, object))

        :param reason:
            The value to assign to the reason property of this KernelCrashEvent.
        :type reason: str

        :param time_first_occurred:
            The value to assign to the time_first_occurred property of this KernelCrashEvent.
        :type time_first_occurred: datetime

        :param vmcore:
            The value to assign to the vmcore property of this KernelCrashEvent.
        :type vmcore: oci.os_management.models.KernelVmCoreInformation

        :param content:
            The value to assign to the content property of this KernelCrashEvent.
        :type content: oci.os_management.models.EventContent

        :param system:
            The value to assign to the system property of this KernelCrashEvent.
        :type system: oci.os_management.models.CrashEventSystemInformation

        """
        self.swagger_types = {
            'id': 'str',
            'instance_id': 'str',
            'compartment_id': 'str',
            'tenancy_id': 'str',
            'summary': 'str',
            'timestamp': 'datetime',
            'event_fingerprint': 'str',
            'count': 'int',
            'event_type': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))',
            'reason': 'str',
            'time_first_occurred': 'datetime',
            'vmcore': 'KernelVmCoreInformation',
            'content': 'EventContent',
            'system': 'CrashEventSystemInformation'
        }

        self.attribute_map = {
            'id': 'id',
            'instance_id': 'instanceId',
            'compartment_id': 'compartmentId',
            'tenancy_id': 'tenancyId',
            'summary': 'summary',
            'timestamp': 'timestamp',
            'event_fingerprint': 'eventFingerprint',
            'count': 'count',
            'event_type': 'eventType',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags',
            'reason': 'reason',
            'time_first_occurred': 'timeFirstOccurred',
            'vmcore': 'vmcore',
            'content': 'content',
            'system': 'system'
        }

        self._id = None
        self._instance_id = None
        self._compartment_id = None
        self._tenancy_id = None
        self._summary = None
        self._timestamp = None
        self._event_fingerprint = None
        self._count = None
        self._event_type = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None
        self._reason = None
        self._time_first_occurred = None
        self._vmcore = None
        self._content = None
        self._system = None
        self._event_type = 'KERNEL_CRASH'

    @property
    def reason(self):
        """
        Gets the reason of this KernelCrashEvent.
        reason of the crash


        :return: The reason of this KernelCrashEvent.
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """
        Sets the reason of this KernelCrashEvent.
        reason of the crash


        :param reason: The reason of this KernelCrashEvent.
        :type: str
        """
        self._reason = reason

    @property
    def time_first_occurred(self):
        """
        Gets the time_first_occurred of this KernelCrashEvent.
        First occurrence time of the event


        :return: The time_first_occurred of this KernelCrashEvent.
        :rtype: datetime
        """
        return self._time_first_occurred

    @time_first_occurred.setter
    def time_first_occurred(self, time_first_occurred):
        """
        Sets the time_first_occurred of this KernelCrashEvent.
        First occurrence time of the event


        :param time_first_occurred: The time_first_occurred of this KernelCrashEvent.
        :type: datetime
        """
        self._time_first_occurred = time_first_occurred

    @property
    def vmcore(self):
        """
        Gets the vmcore of this KernelCrashEvent.

        :return: The vmcore of this KernelCrashEvent.
        :rtype: oci.os_management.models.KernelVmCoreInformation
        """
        return self._vmcore

    @vmcore.setter
    def vmcore(self, vmcore):
        """
        Sets the vmcore of this KernelCrashEvent.

        :param vmcore: The vmcore of this KernelCrashEvent.
        :type: oci.os_management.models.KernelVmCoreInformation
        """
        self._vmcore = vmcore

    @property
    def content(self):
        """
        Gets the content of this KernelCrashEvent.

        :return: The content of this KernelCrashEvent.
        :rtype: oci.os_management.models.EventContent
        """
        return self._content

    @content.setter
    def content(self, content):
        """
        Sets the content of this KernelCrashEvent.

        :param content: The content of this KernelCrashEvent.
        :type: oci.os_management.models.EventContent
        """
        self._content = content

    @property
    def system(self):
        """
        Gets the system of this KernelCrashEvent.

        :return: The system of this KernelCrashEvent.
        :rtype: oci.os_management.models.CrashEventSystemInformation
        """
        return self._system

    @system.setter
    def system(self, system):
        """
        Sets the system of this KernelCrashEvent.

        :param system: The system of this KernelCrashEvent.
        :type: oci.os_management.models.CrashEventSystemInformation
        """
        self._system = system

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
